@@ -18,10 +18,16 @@
  */
 
 
+#include <config.h>
 
 #include <boost/bind.hpp>
 
+#include "sharp/map.hpp"
+#include "sharp/dynamicmodule.hpp"
+
 #include "addinmanager.hpp"
+#include "addinpreferencefactory.hpp"
+#include "debug.hpp"
 #include "watchers.hpp"
 #include "notebooks/notebookapplicationaddin.hpp"
 #include "notebooks/notebooknoteaddin.hpp"
@@ -30,7 +36,7 @@ namespace gnote {
 
 #define REGISTER_NOTE_ADDIN(klass) \
   m_note_addin_infos.insert(std::make_pair(typeid(klass).name(),        \
-  new NoteAddinInfo(sigc::ptr_fun(&klass::create), typeid(klass).name())))
+                                           new sharp::IfaceFactory<klass>))
 
 #define REGISTER_APP_ADDIN(klass) \
   m_app_addins.insert(std::make_pair(typeid(klass).name(),        \
@@ -44,19 +50,13 @@ namespace gnote {
 
   AddinManager::~AddinManager()
   {
-    for(AppAddinMap::const_iterator iter = m_app_addins.begin();
-        iter != m_app_addins.end(); ++iter) {
-      delete iter->second;
-    }
+    sharp::map_delete_all_second(m_app_addins);
     for(NoteAddinMap::const_iterator iter = m_note_addins.begin();
         iter != m_note_addins.end(); ++iter) {
       std::for_each(iter->second.begin(), iter->second.end(), 
                     boost::bind(&boost::checked_delete<NoteAddin>, _1));
     }
-    for(IdInfoMap::const_iterator iter = m_note_addin_infos.begin();
-        iter != m_note_addin_infos.end(); ++iter) {
-      delete iter->second;
-    }
+    sharp::map_delete_all_second(m_addin_prefs);
   }
 
   void AddinManager::initialize_sharp_addins()
@@ -73,6 +73,33 @@ namespace gnote {
     REGISTER_NOTE_ADDIN(notebooks::NotebookNoteAddin);
    
     REGISTER_APP_ADDIN(notebooks::NotebookApplicationAddin);
+
+    m_module_manager.add_path(LIBDIR"/"PACKAGE_NAME"/addins/"PACKAGE_VERSION);
+    m_module_manager.add_path(m_gnote_conf_dir);
+
+    m_module_manager.load_modules();
+
+    const sharp::ModuleList & list = m_module_manager.get_modules();
+    for(sharp::ModuleList::const_iterator iter = list.begin();
+        iter != list.end(); ++iter) {
+
+      sharp::DynamicModule* dmod = *iter;
+      if(!dmod) {
+        continue;
+      }
+
+      sharp::IfaceFactoryBase * f = dmod->query_interface(NoteAddin::IFACE_NAME);
+      if(f) {
+        m_note_addin_infos.insert(std::make_pair(typeid(*f).name(), f));
+      }
+
+      f = dmod->query_interface(AddinPreferenceFactoryBase::IFACE_NAME);
+      if(f) {
+        AddinPreferenceFactoryBase * factory = dynamic_cast<AddinPreferenceFactoryBase*>((*f)());
+        m_addin_prefs.insert(std::make_pair((*iter)->id(), factory));
+      }
+      
+    }
   }
 
   void AddinManager::load_addins_for_note(const Note::Ptr & note)
@@ -84,23 +111,38 @@ namespace gnote {
     for(IdInfoMap::const_iterator iter = m_note_addin_infos.begin();
         iter != m_note_addin_infos.end(); ++iter) {
 
-      const IdInfoMap::value_type & addin_info(*iter);
-      NoteAddin * addin = addin_info.second->factory();
-      addin->initialize(note);
-      loaded.push_back(addin);
+      const IdInfoMap::value_type & addin_info(*iter); 
+      sharp::IInterface* iface = (*addin_info.second)();
+      NoteAddin * addin = dynamic_cast<NoteAddin *>(iface);
+      if(addin) {
+        addin->initialize(note);
+        loaded.push_back(addin);
+      }
+      else {
+        DBG_OUT("wrong type for the interface: %s", typeid(*iface).name());
+        delete iface;
+      }
     }
   }
 
 
-  std::list<ApplicationAddin*> AddinManager::get_application_addins() const
+  void AddinManager::get_application_addins(std::list<ApplicationAddin*> & l) const
   {
-    std::list<ApplicationAddin*> l;
-
-    for(AppAddinMap::const_iterator iter = m_app_addins.begin();
-        iter != m_app_addins.end(); ++iter) {
-      l.push_back(iter->second);
-    }
-    return l;
+    sharp::map_get_values(m_app_addins, l);
   }
 
+
+  void AddinManager::get_preference_tab_addins(std::list<PreferenceTabAddin *> &l) const
+  {
+    sharp::map_get_values(m_pref_tab_addins, l);
+  }
+
+  Gtk::Widget * AddinManager::create_addin_preference_widget(const std::string & id)
+  {
+    IdAddinPrefsMap::const_iterator iter = m_addin_prefs.find(id);
+    if(iter != m_addin_prefs.end()) {
+      return iter->second->create_preference_widget();
+    }
+    return NULL;
+  }
 }
