@@ -33,13 +33,25 @@
 namespace gnote {
 namespace notebooks {
 
+  bool               NotebookNoteAddin::s_static_inited = false;
+  Glib::RefPtr<Gdk::Pixbuf> NotebookNoteAddin::s_notebookIcon;
+  Glib::RefPtr<Gdk::Pixbuf> NotebookNoteAddin::s_newNotebookIcon;
+
+  void NotebookNoteAddin::_init_static()
+  {
+    if(!s_static_inited) {
+      s_notebookIcon = utils::get_icon("notebook", 22);
+      s_newNotebookIcon =  utils::get_icon("notebook-new", 16);
+      s_static_inited = true;
+    }
+  }
+  
 
   NotebookNoteAddin::NotebookNoteAddin()
     : m_toolButton(NULL)
     , m_menu(NULL)
   {
-    m_notebookIcon = utils::get_icon("notebook", 22);
-    m_newNotebookIcon =  utils::get_icon("notebook-new", 16);
+    _init_static();
   }
 
 
@@ -55,7 +67,7 @@ namespace notebooks {
 
   void NotebookNoteAddin::initialize_tool_button()
   {
-    m_toolButton = manage(new Gtk::MenuToolButton(*manage(new Gtk::Image(m_notebookIcon))));
+    m_toolButton = manage(new Gtk::MenuToolButton(*manage(new Gtk::Image(s_notebookIcon))));
     Gtk::Label * l = manage(new Gtk::Label());
     // Ellipsize names longer than 12 chars in length
     // TODO: Should we hardcode the ellipsized notebook name to 12 chars?
@@ -101,7 +113,7 @@ namespace notebooks {
       Tag::Ptr templateTag = TagManager::obj().get_or_create_system_tag (TagManager::TEMPLATE_NOTE_SYSTEM_TAG);
       if (get_note()->contains_tag (templateTag)) {
         m_toolButton->set_sensitive(false);
-				
+        
         // Also prevent notebook templates from being deleted
         if (NotebookManager::instance().get_notebook_from_note (get_note())) {
           get_note()->get_window()->delete_button()->set_sensitive(false);
@@ -173,32 +185,33 @@ namespace notebooks {
     //
     // Build a new menu
     //
-			
+      
     // Add the "New Notebook..."
     Gtk::ImageMenuItem *newNotebookMenuItem =
       manage(new Gtk::ImageMenuItem (_("_New notebook..."), true));
-    newNotebookMenuItem->set_image(*manage(new Gtk::Image (m_newNotebookIcon)));
+    newNotebookMenuItem->set_image(*manage(new Gtk::Image (s_newNotebookIcon)));
     newNotebookMenuItem->signal_activate()
       .connect(sigc::mem_fun(*this,&NotebookNoteAddin::on_new_notebook_menu_item));
     newNotebookMenuItem->show ();
     m_menu->append (*newNotebookMenuItem);
     m_menu_items.push_back(newNotebookMenuItem);
-			
+      
     // Add the "(no notebook)" item at the top of the list
     NotebookMenuItem *noNotebookMenuItem = manage(new NotebookMenuItem (m_radio_group,
                                                     get_note(), Notebook::Ptr()));
     noNotebookMenuItem->show_all ();
     m_menu->append (*noNotebookMenuItem);
     m_menu_items.push_back(noNotebookMenuItem);
-			
+      
     // Add in all the real notebooks
-    std::list<NotebookMenuItem*> notebookMenuItems = get_notebook_menu_items ();
+    std::list<NotebookMenuItem*> notebookMenuItems;
+    get_notebook_menu_items (notebookMenuItems);
     if (!notebookMenuItems.empty()) {
       Gtk::SeparatorMenuItem *separator = manage(new Gtk::SeparatorMenuItem ());
       separator->show_all ();
       m_menu->append (*separator);
       m_menu_items.push_back(separator);
-				
+        
       for(std::list<NotebookMenuItem*>::const_iterator iter = notebookMenuItems.begin();
           iter != notebookMenuItems.end(); ++iter) {
         NotebookMenuItem* item = *iter;
@@ -210,13 +223,13 @@ namespace notebooks {
   }
   
 
-  std::list<NotebookMenuItem*> NotebookNoteAddin::get_notebook_menu_items()
+  void NotebookNoteAddin::get_notebook_menu_items(std::list<NotebookMenuItem*>& items)
   {
-    std::list<NotebookMenuItem*>items;
-			
     Glib::RefPtr<Gtk::TreeModel> model = NotebookManager::instance().get_notebooks();
     Gtk::TreeIter iter;
-			
+
+    items.clear();
+
     iter = model->children().begin();
     for(iter = model->children().begin(); iter != model->children().end(); ++iter) {
       Notebook::Ptr notebook;
@@ -225,10 +238,8 @@ namespace notebooks {
                                                             get_note(), notebook));
       items.push_back (item);
     }
-			
+      
     items.sort ();
-			
-    return items;
   }
 
 
