@@ -1082,12 +1082,16 @@ namespace gnote {
     , m_bold(_("<b>_Bold</b>"), true)
     , m_italic(_("<i>_Italic</i>"), true)
     , m_strikeout(_("<s>_Strikeout</s>"), true)
-    , m_highlight(_("<span background='yellow'>_Highlight</span>"), true)
+    , m_highlight(Glib::ustring("<span background=\"yellow\">")
+                  + _("_Highlight") + "</span>", true)
     , m_fontsize_group()
     , m_normal(m_fontsize_group, _("_Normal"), true)
-    , m_huge(m_fontsize_group, _("<span size=\"x-large\">Hu_ge</span>"), true)
-    , m_large(m_fontsize_group, _("<span size=\"large\">_Large</span>"), true)
-    ,  m_small(m_fontsize_group, _("<span size=\"small\">S_mall</span>"), true)
+    , m_huge(m_fontsize_group, Glib::ustring("<span size=\"x-large\">")
+             + _("Hu_ge") + "</span>", true)
+  , m_large(m_fontsize_group, Glib::ustring("<span size=\"large\">")
+            + _("_Large") + "</span>", true)
+       ,  m_small(m_fontsize_group, Glib::ustring("<span size=\"small\">")
+                  + _("S_mall") + "</span>", true)
     , m_hidden_no_size(m_fontsize_group, "", true)
     , m_bullets(_("Bullets"))
     , m_increase_indent(Gtk::Stock::INDENT)
