@@ -445,8 +445,10 @@ namespace gnote {
       sigc::mem_fun(*this, &NoteUrlWatcher::on_button_press), false);
     editor->signal_populate_popup().connect(
       sigc::mem_fun(*this, &NoteUrlWatcher::on_populate_popup));
+#ifdef HAVE_CLASS_GTK__WIDGET_SIGNAL_POPUP_MENU
     editor->signal_popup_menu().connect(
       sigc::mem_fun(*this, &NoteUrlWatcher::on_popup_menu), false);
+#endif
   }
 
   std::string NoteUrlWatcher::get_url(const Gtk::TextIter & start, const Gtk::TextIter & end)
@@ -481,19 +483,6 @@ namespace gnote {
     return url;
   }
 
-  void NoteUrlWatcher::open_url(const std::string & url)
-    throw (Glib::Error)
-  {
-    if(!url.empty()) {
-      GError *err = NULL;
-      DBG_OUT("Opening url '%s'...", url.c_str());
-      gtk_show_uri (NULL, url.c_str(), GDK_CURRENT_TIME, &err);
-      if(err) {
-        throw Glib::Error(err, true);
-      }
-    }
-  }
-
 
   bool NoteUrlWatcher::on_url_tag_activated(const NoteTag::Ptr &, const NoteEditor &,
                               const Gtk::TextIter & start, const Gtk::TextIter & end)
@@ -501,7 +490,7 @@ namespace gnote {
   {
     std::string url = get_url (start, end);
     try {
-      open_url (url);
+      utils::open_url (url);
     } 
     catch (Glib::Error & e) {
       utils::show_opening_location_error (get_window(), url, e.what());
@@ -587,13 +576,13 @@ namespace gnote {
       item->show ();
       menu->prepend (*item);
 
-      item = manage(new Gtk::MenuItem (_("_Copy Link Address")));
+      item = manage(new Gtk::MenuItem (_("_Copy Link Address"), true));
       item->signal_activate().connect(
         sigc::mem_fun(*this, &NoteUrlWatcher::copy_link_activate));
       item->show ();
       menu->prepend (*item);
 
-      item = manage(new Gtk::MenuItem (_("_Open Link")));
+      item = manage(new Gtk::MenuItem (_("_Open Link"), true));
       item->signal_activate().connect(
         sigc::mem_fun(*this, &NoteUrlWatcher::open_link_activate));
       item->show ();
